# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['ttp_sros_parser', 'ttp_sros_parser.templates']

package_data = \
{'': ['*'],
 'ttp_sros_parser.templates': ['admin_display_file/*',
                               'custom/*',
                               'helpers/*',
                               'show_commands/*']}

install_requires = \
['CacheControl==0.12.6',
 'Cerberus==1.3.2',
 'Jinja2==2.11.2',
 'MarkupSafe==1.1.1',
 'PyNaCl==1.4.0',
 'PyYAML==5.3.1',
 'SecretStorage==3.3.0',
 'appdirs==1.4.4',
 'bcrypt==3.2.0',
 'black==20.8b1',
 'cachy==0.3.0',
 'certifi==2020.12.5',
 'cffi==1.14.4',
 'chardet==4.0.0',
 'cleo==0.8.1',
 'click==7.1.2',
 'clikit==0.6.2',
 'crashtest==0.3.1',
 'cryptography==3.3.1',
 'deepdiff==5.0.2',
 'distlib==0.3.1',
 'filelock==3.0.12',
 'future==0.18.2',
 'html5lib==1.1',
 'idna==2.10',
 'jeepney==0.6.0',
 'keyring==21.5.0',
 'lockfile==0.12.2',
 'msgpack==1.0.2',
 'mypy-extensions==0.4.3',
 'netmiko==3.3.2',
 'nornir==3.0.0',
 'ntc-templates==1.6.0',
 'ordered-set==4.0.2',
 'packaging==20.8',
 'paramiko==2.7.2',
 'pastel==0.2.1',
 'pathspec==0.8.1',
 'pexpect==4.8.0',
 'pkginfo==1.6.1',
 'poetry-core==1.0.0',
 'poetry==1.1.4',
 'ptyprocess==0.6.0',
 'pycparser==2.20',
 'pylev==1.3.0',
 'pyparsing==2.4.7',
 'pyserial==3.5',
 'regex==2020.11.13',
 'requests-toolbelt==0.9.1',
 'requests==2.25.1',
 'ruamel.yaml==0.16.12',
 'scp==0.13.3',
 'shellingham==1.3.2',
 'six==1.15.0',
 'tabulate==0.8.7',
 'tenacity==6.3.1',
 'textfsm==1.1.0',
 'toml==0.10.2',
 'tomlkit==0.7.0',
 'ttp==0.6.0',
 'typed-ast==1.4.1',
 'typing-extensions==3.7.4.3',
 'urllib3==1.26.2',
 'virtualenv==20.2.2',
 'webencodings==0.5.1']

setup_kwargs = {
    'name': 'ttp-sros-parser',
    'version': '0.1.0',
    'description': '',
    'long_description': None,
    'author': 'Hugo',
    'author_email': 'hugotinoco@icloud.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
